==> zhongyan-order-service-api-0.0.6-20220320.074327-1-sources.jar: cn/com/duiba/cloud/zhongyan/order/service/api/remoteservice/RemoteOrderReadService.java <==
package cn.com.duiba.cloud.zhongyan.order.service.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.BackGroudOrderDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.ExportOrderDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.LogisticsDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.OrderDetailDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.OrderStatusCountDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.OrderStatusDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.SkuSaleNumberDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.SubOrderGoodsDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.UserOrderDetailDTO;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.ExportOrderParam;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.OrderQueryParam;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.OrderStatusCountParam;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * @Description 订单相关读操作接口
 * @Author dangcang
 * @Date 2021/11/10 1:37 下午
 **/
@AdvancedFeignClient
public interface RemoteOrderReadService {

    /**
     * 分页查询订单接口--后台
     * @param param
     * @return
     * @throws BizException
     */
    PageResponse<BackGroudOrderDTO> backGroundFind(OrderQueryParam param) throws BizException;

    /**
     * 订单导出
     * @param param
     * @return
     * @throws BizException
     */
    ExportOrderDTO exportOrderList(ExportOrderParam param) throws BizException;

    /**
     * 获取订单商品信息、发货信息--后台
     * @param orderCode
     * @return
     * @throws BizException
     */
    LogisticsDTO getLogisticsMsg(String orderCode) throws BizException;

    /**
     * 获取订单详情--后台
     * @param orderCode
     * @return
     * @throws BizException
     */
    OrderDetailDTO backgroundGetOrderDetail(String orderCode) throws BizException;

    /**
     * 获取用户订单详情
     * @param orderCode
     * @return
     * @throws BizException
     */
    UserOrderDetailDTO getUserOrderDetail(String orderCode) throws BizException;

    /**
     * 后台获取订单状态下的订单数量
     * @param param
     * @return
     * @throws BizException
     */
    List<OrderStatusCountDTO> backGroundGetStatusCount(OrderStatusCountParam param) throws BizException;

    /**
     * 获取子订单信息列表
     * @param orderCode
     * @param orderSortList
     * @return
     * @throws BizException
     */
    List<SubOrderGoodsDTO> getSubOrderList(String orderCode, List<Integer> orderSortList) throws BizException;

    /**
     * 根据订单号查询主订单状态
     * @param orderCodeList
     * @return
     * @throws BizException
     */
    List<OrderStatusDTO> getOrderStatusByOrderCodeList(List<String> orderCodeList) throws BizException;

    /**
     * 批量获取sku销量
     * @param skuIdList
     * @return
     */
    @Deprecated
    List<SkuSaleNumberDTO> getSkuSaleNum(List<Long> skuIdList);

}

==> zhongyan-order-service-api-0.0.12-sources.jar: cn/com/duiba/cloud/zhongyan/order/service/api/remoteservice/RemoteOrderReadService.java <==
package cn.com.duiba.cloud.zhongyan.order.service.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.dto.*;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.ExportOrderParam;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.OrderQueryParam;
import cn.com.duiba.cloud.zhongyan.order.service.api.model.param.OrderStatusCountParam;
import cn.com.duiba.wolf.entity.PageResponse;

import java.util.List;

/**
 * @Description 订单相关读操作接口
 * @Author dangcang
 * @Date 2021/11/10 1:37 下午
 **/
@AdvancedFeignClient
public interface RemoteOrderReadService {

    /**
     * 分页查询订单接口--后台
     * @param param
     * @return
     * @throws BizException
     */
    PageResponse<BackGroudOrderDTO> backGroundFind(OrderQueryParam param) throws BizException;

    /**
     * 订单导出
     * @param param
     * @return
     * @throws BizException
     */
    ExportOrderDTO exportOrderList(ExportOrderParam param) throws BizException;

    /**
     * 获取订单商品信息、发货信息--后台
     * @param orderCode
     * @return
     * @throws BizException
     */
    LogisticsDTO getLogisticsMsg(String orderCode) throws BizException;

    /**
     * 获取订单详情--后台
     * @param orderCode
     * @return
     * @throws BizException
     */
    OrderDetailDTO backgroundGetOrderDetail(String orderCode) throws BizException;

    /**
     * 获取用户订单详情
     * @param orderCode
     * @return
     * @throws BizException
     */
    UserOrderDetailDTO getUserOrderDetail(String orderCode) throws BizException;

    /**
     * 后台获取订单状态下的订单数量
     * @param param
     * @return
     * @throws BizException
     */
    List<OrderStatusCountDTO> backGroundGetStatusCount(OrderStatusCountParam param) throws BizException;

    /**
     * 获取子订单信息列表
     * @param orderCode
     * @param orderSortList
     * @return
     * @throws BizException
     */
    List<SubOrderGoodsDTO> getSubOrderList(String orderCode, List<Integer> orderSortList) throws BizException;

    /**
     * 根据订单号查询主订单状态
     * @param orderCodeList
     * @return
     * @throws BizException
     */
    List<OrderStatusDTO> getOrderStatusByOrderCodeList(List<String> orderCodeList) throws BizException;

    /**
     * 批量获取sku销量
     * @param skuIdList
     * @return
     */
    @Deprecated
    List<SkuSaleNumberDTO> getSkuSaleNum(List<Long> skuIdList);

    /**
     * 批量获取订单收货地址
     * @param orderCodeList
     * @return
     * @throws BizException
     */
    List<OrderAddressDTO> batchOrderAddressList(List<String> orderCodeList) throws BizException;

}
